/* testing TestRGF.java, Rony G. Flatscher, 2001-04-25, 2003-05-10

   purpose: this Rexx program demonstrates the usage of the Java class "TestRGF"
            and demonstrates the usage of the BSF-interface, concentrating on
            accessing arrays

   invoke:  enter the following command to inoke the Rexx program "testArrays-oo.bat"

                  "java com.ibm.bsf.Main -lang rexx -in testArrays-oo.rex"
            or
                  "java com.ibm.bsf.Main -in testArrays-oo.rex"

            if extension "rex" is defined in the text file "\com\ibm\bsf\Languages.properties",
            which allows for determining the needed engine by looking at the file extension
*/

if rxFuncQuery("BSF") then  /* no bsf4rexx support available yet, hence load Java */
do
   call rxFuncAdd "BsfLoadFuncs", "BSF4Rexx", "BsfLoadFuncs"
   call BsfLoadFuncs    /* load all BSF-functions                    */
   call BsfLoadJava     /* load the JVM and set up BSF4Rexx-support  */
end

if      BsfInvokedBy()=1 then say "This Rexx program was invoked by Java!"
else if BsfInvokedBy()=2 then say "This Rexx program was invoked by Rexx, JVM loaded by Rexx!"
else                          say "No JVM present, we got troubles ..."

tr1 = "tr1"
type = "com.ibm.bsf.engines.rexx.test.TestRGF"
type = "TestRGF"

say "Registering bean ..."
tr1 = bsf( "registerBean", , type)

f3 = bsf("getFieldValue", tr1, "statField3")
f4 = bsf("getFieldValue", tr1, "statField4")
f5 = bsf("getFieldValue", tr1, "statField5")
f6 = bsf("getFieldValue", tr1, "statField6")
f7 = bsf("getFieldValue", tr1, "statField7")

say
call dump_array f3
say
call bsf "arrayPut", f3, "un"    , 0
call bsf "arrayPut", f4, "deux"  , 0, 1
call bsf "arrayPut", f5, "trois" , 0, 1, 2
call bsf "arrayPut", f6, "quatre", 0, 1, 2, 3
call bsf "arrayPut", f7, "cinq"  , 0, 1, 2, 3, 4

say left("", 79, "-")
say
say "Now retrieving the stored values from the arrays:"
say
say "statField3[0]            : [" || bsf("arrayAt", f3, 0            ) || "]"
say "statField4[0][1]         : [" || bsf("arrayAt", f4, 0, 1         ) || "]"
say "statField5[0][1][2]      : [" || bsf("arrayAt", f5, 0, 1, 2      ) || "]"
say "statField6[0][1][2][3]   : [" || bsf("arrayAt", f6, 0, 1, 2, 3   ) || "]"
say "statField7[0][1][2][3][4]: [" || bsf("arrayAt", f7, 0, 1, 2, 3, 4) || "]"

say left("", 79, "-")


say
say "trying to get the field length of the array:"
say
f7a=bsf("arrayAt", f7, 0            )
f7b=bsf("arrayAt", f7, 0, 0         )
f7c=bsf("arrayAt", f7, 0, 0, 0      )
f7d=bsf("arrayAt", f7, 0, 0, 0, 0   )
f7e=bsf("arrayAt", f7, 0, 0, 0, 0, 0)
say "f7a: [" || (f7a) || "] ..."
say "f7b: [" || (f7b) || "] ..."
say "f7c: [" || (f7c) || "] ..."
say "f7d: [" || (f7d) || "] ..."
say

say "trying to get to the static method of the array-util-class:"
say
say "length of f7 :" bsf("arrayLength", f7 )  "length (size) of first dimension"
say "length of f7a:" bsf("arrayLength", f7a)  "length (size) of second dimension"
say "length of f7b:" bsf("arrayLength", f7b)  "length (size) of third dimension"
say "length of f7c:" bsf("arrayLength", f7c)  "length (size) of fourth dimension"
say "length of f7d:" bsf("arrayLength", f7d)  "length (size) of fifth dimension"
say
call dump_array f3
exit

dump_array: procedure
   parse arg javaArray

   say left("", 79, "-")
   say
   say "looping over <"javaArray">:"
   say
   do i=0 to bsf("arraylength", javaArray)-1   /* note Java-arrays are 0-based!                        */
      say "Java-index:" i "value: [" || bsf("arrayAt", javaArray, i) || "]"
   end
   return

